@@ -10,13 +10,13 @@ class IRB::Context
     RBTraceCLI.tracer.print(arg)
   end
 
-  def inspect_last_value
+  def inspect_last_value(output = +"")
     @last_value
   end
 end
 
 class IRB::WorkSpace
-  def evaluate(context, statements, file=__FILE__, line=__LINE__)
+  def evaluate(statements, file=__FILE__, line=__LINE__)
     RBTraceCLI.tracer.eval(statements)
   end
 end
